{% extends "basic/layout.html" %}

{% set script_files = script_files + ["_static/ga-1.js"] %}
{% set script_files = script_files + ["_static/ga-2.js"] %}

{% block rootrellink %}
    <li><a href="http://music.columbia.edu/cmc/chiplotle/">Chiplotle</a> &raquo;</li>
     {{ super() }}
{% endblock %}


